To reference stsynphot in publications, please cite [![ascl:2010.003](https://img.shields.io/badge/ascl-2010.003-blue.svg?colorB=262255)](https://ascl.net/2010.003)

#### Other forms of citation

[![DOI](https://zenodo.org/badge/12412342.svg)](https://zenodo.org/doi/10.5281/zenodo.5020767)

Lim, P. L., et al. 2016, stsynphot User's Guide (Baltimore, MD: STScI),
https://stsynphot.readthedocs.io/en/latest/
